@@ -1,17 +1,14 @@
-import unittest
-
-# FIXME Our Windows build server does not support GStreamer yet
 import sys
-if sys.platform == 'win32':
-    from tests import SkipTest
-    raise SkipTest
 
 from mopidy import settings
 from mopidy.backends.local import LocalBackend
 
-from tests import path_to_data_dir
+from tests import unittest, path_to_data_dir
 from tests.backends.base.library import LibraryControllerTest
 
+
+@unittest.skipIf(sys.platform == 'win32',
+    'Our Windows build server does not support GStreamer yet')
 class LocalLibraryControllerTest(LibraryControllerTest, unittest.TestCase):
 
     backend_class = LocalBackend
