@@ -2,7 +2,6 @@ from mopidy.backends.dummy import DummyBackend
 from mopidy.frontends.mpd.dispatcher import MpdDispatcher
 from mopidy.frontends.mpd.exceptions import MpdAckError
 from mopidy.frontends.mpd.protocol import request_handlers, handle_request
-from mopidy.mixers.dummy import DummyMixer
 
 from tests import unittest
 
@@ -10,12 +9,10 @@ from tests import unittest
 class MpdDispatcherTest(unittest.TestCase):
     def setUp(self):
         self.backend = DummyBackend.start().proxy()
-        self.mixer = DummyMixer.start().proxy()
         self.dispatcher = MpdDispatcher()
 
     def tearDown(self):
         self.backend.stop().get()
-        self.mixer.stop().get()
 
     def test_register_same_pattern_twice_fails(self):
         func = lambda: None
@@ -40,7 +37,7 @@ class MpdDispatcherTest(unittest.TestCase):
             expected_handler
         (handler, kwargs) = self.dispatcher._find_handler('known_command an_arg')
         self.assertEqual(handler, expected_handler)
-        self.assert_('arg1' in kwargs)
+        self.assertIn('arg1', kwargs)
         self.assertEqual(kwargs['arg1'], 'an_arg')
 
     def test_handling_unknown_request_yields_error(self):
@@ -51,5 +48,5 @@ class MpdDispatcherTest(unittest.TestCase):
         expected = 'magic'
         request_handlers['known request'] = lambda x: expected
         result = self.dispatcher.handle_request('known request')
-        self.assert_(u'OK' in result)
-        self.assert_(expected in result)
+        self.assertIn(u'OK', result)
+        self.assertIn(expected, result)
